from setuptools import setup, find_packages
setup(
    name='corinvo',
    version='0.1.0',
    author='Corinvo Open Source Team',
    author_email='your.email@example.com',
    description='This package name is reserved by Corinvo LLC',
    packages=find_packages(),
    classifiers=[
    'Programming Language :: Python :: 3',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
